Changelog
=========

Version 2.0.0
#############

Features
--------

 * New, responsive, theme.
 * Board templates (save board as template, create board from template).
 * Shared boards  (public boards that are advertised on home pages).
 * Optional identicons.
 * Various UX improvements.
 * More control upon image backgrounds.
 * Week view in calendar.
 * No more "Synchronization errors"; replaced by auto-refresh.
 * Performance improvements, lower latency.
 * New wysiwig editor.
 * Turkish language support.
 * Japanese language support.
 * Many, many bug fixes.

Developer
---------

 * Cleaner Card code.
 * Card plugin extensions.
 * Service injection.
 * Pluggable theme.
 * Reorganised authentication modules.

